.. _AUTHORS:

Current and previous contributors
=================================

Development
~~~~~~~~~~~

* Rikard Nordgren, rikard.nordgren@farmaci.uu.se, (maintainer)
* Stella Belin, stella.belin@farmaci.uu.se, (maintainer)
* Gunnar Yngman, gunnar.yngman@farmaci.uu.se
* Kajsa Harling

Research and scientific advice
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Mats O. Karlsson
* Andrew C. Hooker
* Sebastian Ueckert
* Simon Carter
* Simon Buatois
* João A. Abrantes

Funding
~~~~~~~

* F. Hoffman-La Roche Ltd.
* Pharmetheus
* Uppsala University
